length_which: Count values that satisfy a condition

Description Usage Arguments Value

View source: R/functions.R

Description

Count values that satisfy a condition

Usage

1

Arguments

condition

The condition for which values are to be counted. Must be type logical

Value

An integer with the count of values that satisfy the condition.


jfeldhege/convenienceFunctions documentation built on May 30, 2021, 4:17 a.m.