Description Usage Arguments Value
Count values that satisfy a condition
1 |
condition |
The condition for which values are to be counted. Must be type logical |
An integer with the count of values that satisfy the condition.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.